==> razorqt_0.4.1.orig.tar.xz: razorqt-0.4.1/razorqt-panel/plugin-taskbar/translations/taskbar_cs_CZ.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="cs_CZ">
<context>
    <name>RazorTaskButton</name>
    <message>
        <location filename="../razortaskbutton.cpp" line="360"/>
        <source>Application</source>
        <translation>Program</translation>
    </message>
    <message>
        <location filename="../razortaskbutton.cpp" line="393"/>
        <source>To &amp;Desktop</source>
        <translation>Na &amp;plochu</translation>
    </message>
    <message>
        <location filename="../razortaskbutton.cpp" line="395"/>
        <source>&amp;All Desktops</source>
        <translation>&amp;Všechny plochy</translation>
    </message>
    <message>
        <location filename="../razortaskbutton.cpp" line="402"/>
        <source>Desktop &amp;%1</source>
        <translation>Plocha &amp;%1</translation>
    </message>
    <message>
        <location filename="../razortaskbutton.cpp" line="409"/>
        <source>&amp;To Current Desktop</source>
        <translation>&amp;Na nynější plochu</translation>
    </message>
    <message>
        <location filename="../razortaskbutton.cpp" line="418"/>
        <source>Ma&amp;ximize</source>
        <translation>Zvě&amp;tšit</translation>
    </message>
    <message>
        <location filename="../razortaskbutton.cpp" line="427"/>
        <source>Maximize vertically</source>
        <translation>Zvětšit svisle</translation>
    </message>
    <message>
        <location filename="../razortaskbutton.cpp" line="432"/>
        <source>Maximize horizontally</source>
        <translation>Zvětšit vodorovně</translation>
    </message>
    <message>
        <location filename="../razortaskbutton.cpp" line="438"/>
        <source>&amp;Restore</source>
        <translation>&amp;Obnovit</translation>
    </message>
    <message>
        <location filename="../razortaskbutton.cpp" line="442"/>
        <source>Mi&amp;nimize</source>
        <translation>&amp;Zmenšit</translation>
    </message>
    <message>
        <location filename="../razortaskbutton.cpp" line="448"/>
        <source>Roll down</source>
        <translation>Sbalit</translation>
    </message>
    <message>
        <location filename="../razortaskbutton.cpp" line="454"/>
        <source>Roll up</source>
        <translation>Rozbalit</translation>
    </message>
    <message>
        <location filename="../razortaskbutton.cpp" line="463"/>
        <source>&amp;Layer</source>
        <translation>&amp;Vrstva</translation>
    </message>
    <message>
        <location filename="../razortaskbutton.cpp" line="465"/>
        <source>Always on &amp;top</source>
        <translation>Vždy &amp;nahoře</translation>
    </message>
    <message>
        <location filename="../razortaskbutton.cpp" line="470"/>
        <source>&amp;Normal</source>
        <translation>&amp;Obvyklé</translation>
    </message>
    <message>
        <location filename="../razortaskbutton.cpp" line="475"/>
        <source>Always on &amp;bottom</source>
        <translation>Vždy &amp;dole</translation>
    </message>
    <message>
        <location filename="../razortaskbutton.cpp" line="483"/>
        <source>&amp;Close</source>
        <translation>&amp;Zavřít</translation>
    </message>
</context>
<context>
    <name>RazorTaskbarConfiguration</name>
    <message>
        <location filename="../razortaskbarconfiguration.ui" line="14"/>
        <source>Razor Task Manager Settings</source>
        <translation>Nastavení správce úkolů</translation>
    </message>
    <message>
        <location filename="../razortaskbarconfiguration.ui" line="20"/>
        <source>Window List Content</source>
        <translation>Obsah seznamu oken</translation>
    </message>
    <message>
        <location filename="../razortaskbarconfiguration.ui" line="26"/>
        <source>Show windows from current desktop</source>
        <translation>Ukázat okna z nynější plochy</translation>
    </message>
    <message>
        <location filename="../razortaskbarconfiguration.ui" line="29"/>
        <location filename="../razortaskbarconfiguration.ui" line="39"/>
        <source>wlcB</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../razortaskbarconfiguration.ui" line="36"/>
        <source>Show windows from all desktops</source>
        <translation>Ukázat okna ze všech ploch</translation>
    </message>
    <message>
        <location filename="../razortaskbarconfiguration.ui" line="49"/>
        <source>Window List Appearance</source>
        <translation>Vzhled seznamu oken</translation>
    </message>
    <message>
        <location filename="../razortaskbarconfiguration.ui" line="55"/>
        <source>Button style</source>
        <translation>Styl tlačítek</translation>
    </message>
    <message>
        <location filename="../razortaskbarconfiguration.ui" line="65"/>
        <source>Max button width</source>
        <translation>Největší šířka tlačítka</translation>
    </message>
    <message>
        <location filename="../razortaskbarconfiguration.cpp" line="41"/>
        <source>Icon and text</source>
        <translation>Ikona a text</translation>
    </message>
    <message>
        <location filename="../razortaskbarconfiguration.cpp" line="42"/>
        <source>Only icon</source>
        <translation>Pouze ikona</translation>
    </message>
    <message>
        <location filename="../razortaskbarconfiguration.cpp" line="43"/>
        <source>Only text</source>
        <translation>Pouze text</translation>
    </message>
</context>
</TS>

==> razorqt_0.5.2.orig.tar.xz: razorqt-0.5.2/razorqt-panel/plugin-taskbar/translations/taskbar_cs_CZ.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="cs_CZ" version="2.0">
<context>
    <name>RazorTaskButton</name>
    <message>
        <source>Application</source>
        <translation>Program</translation>
    </message>
    <message>
        <source>To &amp;Desktop</source>
        <translation>Na &amp;plochu</translation>
    </message>
    <message>
        <source>&amp;All Desktops</source>
        <translation>&amp;Všechny plochy</translation>
    </message>
    <message>
        <source>Desktop &amp;%1</source>
        <translation>Plocha &amp;%1</translation>
    </message>
    <message>
        <source>&amp;To Current Desktop</source>
        <translation>&amp;Na nynější plochu</translation>
    </message>
    <message>
        <source>Ma&amp;ximize</source>
        <translation>Zvě&amp;tšit</translation>
    </message>
    <message>
        <source>Maximize vertically</source>
        <translation>Zvětšit svisle</translation>
    </message>
    <message>
        <source>Maximize horizontally</source>
        <translation>Zvětšit vodorovně</translation>
    </message>
    <message>
        <source>&amp;Restore</source>
        <translation>&amp;Obnovit</translation>
    </message>
    <message>
        <source>Mi&amp;nimize</source>
        <translation>&amp;Zmenšit</translation>
    </message>
    <message>
        <source>Roll down</source>
        <translation>Sbalit</translation>
    </message>
    <message>
        <source>Roll up</source>
        <translation>Rozbalit</translation>
    </message>
    <message>
        <source>&amp;Layer</source>
        <translation>&amp;Vrstva</translation>
    </message>
    <message>
        <source>Always on &amp;top</source>
        <translation>Vždy &amp;nahoře</translation>
    </message>
    <message>
        <source>&amp;Normal</source>
        <translation>&amp;Obvyklé</translation>
    </message>
    <message>
        <source>Always on &amp;bottom</source>
        <translation>Vždy &amp;dole</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation>&amp;Zavřít</translation>
    </message>
</context>
<context>
    <name>RazorTaskbarConfiguration</name>
    <message>
        <source>Razor Task Manager Settings</source>
        <translation>Nastavení správce úkolů</translation>
    </message>
    <message>
        <source>Window List Content</source>
        <translation>Obsah seznamu oken</translation>
    </message>
    <message>
        <source>Show windows from current desktop</source>
        <translation>Ukázat okna z nynější plochy</translation>
    </message>
    <message>
        <source>Show windows from all desktops</source>
        <translation>Ukázat okna ze všech ploch</translation>
    </message>
    <message>
        <source>Window List Appearance</source>
        <translation>Vzhled seznamu oken</translation>
    </message>
    <message>
        <source>Button style</source>
        <translation>Styl tlačítek</translation>
    </message>
    <message>
        <source>Max button width</source>
        <translation>Největší šířka tlačítka</translation>
    </message>
    <message>
        <source>Close on middle-click</source>
        <translation>Zavřít klepnutím prostředním tlačítkem</translation>
    </message>
    <message>
        <source>Icon and text</source>
        <translation>Ikona a text</translation>
    </message>
    <message>
        <source>Only icon</source>
        <translation>Pouze ikona</translation>
    </message>
    <message>
        <source>Only text</source>
        <translation>Pouze text</translation>
    </message>
</context>
</TS>
